Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1296)

Unified Diff: chrome/app/chrome_main_delegate.cc

Issue 2769023004: Cloud Print process type: service -> cloud-print-service (Closed)
Patch Set: . Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/app/main_dll_loader_win.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/app/chrome_main_delegate.cc
diff --git a/chrome/app/chrome_main_delegate.cc b/chrome/app/chrome_main_delegate.cc
index 8a4e8f2e458d3cf2c5a48a43e3512b083dd95fab..bcc8d8c80f8effc184ffa5593c6a6badaca0fde1 100644
--- a/chrome/app/chrome_main_delegate.cc
+++ b/chrome/app/chrome_main_delegate.cc
@@ -170,7 +170,7 @@ base::LazyInstance<ChromeCrashReporterClient>::Leaky g_chrome_crash_client =
#endif
extern int NaClMain(const content::MainFunctionParams&);
-extern int ServiceProcessMain(const content::MainFunctionParams&);
+extern int CloudPrintServiceProcessMain(const content::MainFunctionParams&);
namespace {
@@ -250,7 +250,7 @@ void AdjustLinuxOOMScore(const std::string& process_type) {
score = kPluginScore + kScoreBump;
} else if (process_type == switches::kUtilityProcess ||
process_type == switches::kGpuProcess ||
- process_type == switches::kServiceProcess) {
+ process_type == switches::kCloudPrintServiceProcess) {
score = kMiscScore;
#ifndef DISABLE_NACL
} else if (process_type == switches::kNaClLoaderProcess ||
@@ -940,24 +940,24 @@ void ChromeMainDelegate::SandboxInitialized(const std::string& process_type) {
int ChromeMainDelegate::RunProcess(
const std::string& process_type,
const content::MainFunctionParams& main_function_params) {
// ANDROID doesn't support "service", so no ServiceProcessMain, and arraysize
// doesn't support empty array. So we comment out the block for Android.
#if !defined(OS_ANDROID)
static const MainFunction kMainFunctions[] = {
#if BUILDFLAG(ENABLE_PRINT_PREVIEW) && !defined(CHROME_MULTIPLE_DLL_CHILD)
- { switches::kServiceProcess, ServiceProcessMain },
+ {switches::kCloudPrintServiceProcess, CloudPrintServiceProcessMain},
#endif
#if defined(OS_MACOSX)
- { switches::kRelauncherProcess,
- mac_relauncher::internal::RelauncherMain },
+ {switches::kRelauncherProcess, mac_relauncher::internal::RelauncherMain},
#endif
// This entry is not needed on Linux, where the NaCl loader
// process is launched via nacl_helper instead.
#if !defined(DISABLE_NACL) && !defined(CHROME_MULTIPLE_DLL_BROWSER) && \
!defined(OS_LINUX)
- { switches::kNaClLoaderProcess, NaClMain },
+ {switches::kNaClLoaderProcess, NaClMain},
#else
{ "<invalid>", NULL }, // To avoid constant array of size 0
// when DISABLE_NACL and CHROME_MULTIPLE_DLL_CHILD
@@ -996,7 +996,7 @@ bool ChromeMainDelegate::ProcessRegistersWithSystemProcess(
bool ChromeMainDelegate::ShouldSendMachPort(const std::string& process_type) {
return process_type != switches::kRelauncherProcess &&
- process_type != switches::kServiceProcess;
+ process_type != switches::kCloudPrintServiceProcess;
}
bool ChromeMainDelegate::DelaySandboxInitialization(
« no previous file with comments | « no previous file | chrome/app/main_dll_loader_win.cc » ('j') | no next file with comments »
@@ -940,24 +940,24 @@ void ChromeMainDelegate::SandboxInitialized(const std::string& process_type) {
const std::string& process_type,
const content::MainFunctionParams& main_function_params) {
- // ANDROID doesn't support "service", so no ServiceProcessMain, and arraysize
- // doesn't support empty array. So we comment out the block for Android.
+// ANDROID doesn't support "cloud-print-service", so no
+// CloudPrintServiceProcessMain, and arraysize doesn't support empty array. So
+// we comment out the block for Android.
#if !defined(OS_ANDROID)
static const MainFunction kMainFunctions[] = {

Powered by Google App Engine
This is Rietveld 408576698